@@ -754,6 +754,7 @@ class XmlDriver extends FileDriver
       *                   scale?: int,
       *                   unique?: bool,
       *                   nullable?: bool,
+      *                   index?: bool,
       *                   notInsertable?: bool,
       *                   notUpdatable?: bool,
       *                   enumType?: string,
@@ -792,6 +793,10 @@ class XmlDriver extends FileDriver
             $mapping['unique'] = $this->evaluateBoolean($fieldMapping['unique']);
         }
 
+        if (isset($fieldMapping['index'])) {
+            $mapping['index'] = $this->evaluateBoolean($fieldMapping['index']);
+        }
+
         if (isset($fieldMapping['nullable'])) {
             $mapping['nullable'] = $this->evaluateBoolean($fieldMapping['nullable']);
         }
