@@ -505,6 +505,11 @@ class SchemaTool
         if ($isUnique) {
             $table->addUniqueIndex([$columnName]);
         }
+
+        $isIndex = $mapping->index ?? false;
+        if ($isIndex) {
+            $table->addIndex([$columnName]);
+        }
     }
 
     /**
@@ -718,6 +723,10 @@ class SchemaTool
             if (isset($joinColumn->onDelete)) {
                 $fkOptions['onDelete'] = $joinColumn->onDelete;
             }
+
+            if (isset($joinColumn->deferrable)) {
+                $fkOptions['deferrable'] = $joinColumn->deferrable;
+            }
         }
 
         // Prefer unique constraints over implicit simple indexes created for foreign keys.
