@@ -14,24 +14,24 @@ use Doctrine\ORM\Query\SqlOutputWalker;
 /**
  * SqlWalker implementation that does not produce SQL.
  */
-class NullSqlWalker extends SqlOutputWalker
+final class NullSqlWalker extends SqlOutputWalker
 {
-    public function walkSelectStatement(AST\SelectStatement $AST): string
+    public function walkSelectStatement(AST\SelectStatement $selectStatement): string
     {
         return '';
     }
 
-    public function walkUpdateStatement(AST\UpdateStatement $AST): string
+    public function walkUpdateStatement(AST\UpdateStatement $updateStatement): string
     {
         return '';
     }
 
-    public function walkDeleteStatement(AST\DeleteStatement $AST): string
+    public function walkDeleteStatement(AST\DeleteStatement $deleteStatement): string
     {
         return '';
     }
 
-    public function getFinalizer($AST): SqlFinalizer
+    public function getFinalizer(AST\SelectStatement|AST\UpdateStatement|AST\DeleteStatement $statement): SqlFinalizer
     {
         return new PreparedExecutorFinalizer(
             new class extends AbstractSqlExecutor {
@@ -39,7 +39,7 @@ class NullSqlWalker extends SqlOutputWalker
                 {
                     return 0;
                 }
-            }
+            },
         );
     }
 }
