@@ -6,7 +6,6 @@ namespace Doctrine\Tests\Models\Company;
 
 use Doctrine\ORM\Event\PrePersistEventArgs;
 use Doctrine\ORM\Mapping as ORM;
-use Doctrine\ORM\Mapping\PrePersist;
 
 use function func_get_args;
 
@@ -15,14 +14,12 @@ class CompanyFlexUltraContractListener
     /** @phpstan-var list<mixed[]> */
     public $prePersistCalls;
 
-    /** @PrePersist */
     #[ORM\PrePersist]
     public function prePersistHandler1(CompanyContract $contract, PrePersistEventArgs $args): void
     {
         $this->prePersistCalls[] = func_get_args();
     }
 
-    /** @PrePersist */
     #[ORM\PrePersist]
     public function prePersistHandler2(CompanyContract $contract, PrePersistEventArgs $args): void
     {
