@@ -13,28 +13,19 @@ use Doctrine\ORM\Mapping\OneToMany;
 use Doctrine\ORM\Mapping\Table;
 use Doctrine\Tests\DbalTypes\CustomIdObject;
 
-/**
- * @Entity
- * @Table(name="custom_id_type_parent")
- */
+#[Table(name: 'custom_id_type_parent')]
+#[Entity]
 class CustomIdObjectTypeParent
 {
-    /**
-     * @Id
-     * @Column(type="CustomIdObject", length=255)
-     * @var CustomIdObject
-     */
-    public $id;
-
-    /**
-     * @phpstan-var Collection<int, CustomIdObjectTypeChild>
-     * @OneToMany(targetEntity="Doctrine\Tests\Models\CustomType\CustomIdObjectTypeChild", cascade={"persist", "remove"}, mappedBy="parent")
-     */
+    /** @phpstan-var Collection<int, CustomIdObjectTypeChild> */
+    #[OneToMany(targetEntity: 'Doctrine\Tests\Models\CustomType\CustomIdObjectTypeChild', cascade: ['persist', 'remove'], mappedBy: 'parent')]
     public $children;
 
-    public function __construct(CustomIdObject $id)
-    {
-        $this->id       = $id;
+    public function __construct(
+        #[Id]
+        #[Column(type: 'CustomIdObject', length: 255)]
+        public CustomIdObject $id,
+    ) {
         $this->children = new ArrayCollection();
     }
 }
