@@ -134,7 +134,7 @@ class LifecycleCallbackTest extends OrmFunctionalTestCase
         LifecycleCallbackTestEntity::$postLoadCallbackInvoked = false; // Reset the tracking of the postLoad invocation
 
         $reference = $this->_em->getReference(LifecycleCallbackTestEntity::class, $id);
-        self::assertFalse($reference::$postLoadCallbackInvoked);
+        self::assertArrayNotHasKey('postLoadCallbackInvoked', (array) $reference);
         $this->assertTrue($this->isUninitializedObject($reference));
 
         $reference->getValue(); // trigger proxy load
