@@ -66,7 +66,7 @@ class AttributeDriverTest extends MappingDriverTestCase
                     'name' => 'assoz_id',
                     'referencedColumnName' => 'assoz_id',
                     'unique' => false,
-                    'nullable' => true,
+                    'nullable' => null,
                     'onDelete' => null,
                     'columnDefinition' => null,
                 ]),
@@ -80,7 +80,7 @@ class AttributeDriverTest extends MappingDriverTestCase
                     'name' => 'inverse_assoz_id',
                     'referencedColumnName' => 'inverse_assoz_id',
                     'unique' => false,
-                    'nullable' => true,
+                    'nullable' => null,
                     'onDelete' => null,
                     'columnDefinition' => null,
                 ]),
